
0.10.0 (2023-11-17)
------------------

- fix CSS child selectors
- disable loading remote stylesheets when inlining CSS
- require css-inline 0.11.x for performance improvements
- drop css-inline Python 3.6 support
- fix exception when processing an `mj-section` with `background-size` (reported by Thomas Handorf)


0.9.1 (2023-09-23)
------------------

- require css_inline < 0.10 due to an incompatible API change
- move project out of "alpha" state, it is at least "beta" by now


0.9.0 (2023-05-25)
------------------

- add mjml-accordion, mjml-accordion-element, mjml-accordion-text, mjml-accordion-title, mjml-carousel, mjml-head-breakpoint, mjml-hero, mjml-navbar, mjml-navbar-link, mjml-social, mjml-spacer, and mjml-wrapper components (Casey Holzer)
- add support for custom components (Casey Holzer)
- add support for full-width attribute to mj-section (Casey Holzer)
- renamed project to "mjml-python", dropping the "-stub" suffix


0.8.0 (2022-08-25)
------------------

- parse MJML using BeautifulSoup4 which fixes several issues with HTML inside
  `mj-text` (e.g. HTML entities, missing white space) (Casey Holzer)
- prevent exception when trying to set padding for `<mj-column>` (reported by Peter Coles)
- fix setting `width` attribute for `mj-button` (spotted by Michael Romanenko)
- support css inlining (via `inlineStyle`) if "css_inline" is installed (Casey Holzer)

**New Contributors:**

- [Casey Holzer](https://www.github.com/caseyjhol)
- [Peter Coles](https://www.github.com/mrcoles)


0.7.0 (2022-03-24)
------------------

- fix incomplete implementation of `background` attributes for `<mj-section>`
- check HTML output against mjml 4.12.0: test suite was updated with outputs
  from mjml 4.12.0 and required fixes where ported.


0.6.2 (2021-06-01)
------------------

- fix non-ascii content in included files on Windows


0.6.1 (2021-04-15)
------------------

- mj-button: prevent target="_blank" for mailto links (Thunderbird)
- fix `<mj-include>`
- update test suite to check against html generated by mjml 4.9.0 and
  port required fixes to get the test suite passing.
- fix `<mj-image>` with `href` attribute


0.6.0 (2021-03-23)
------------------

- support `<mj-include>` for body components
- mjml_to_html(): also accept plain strings as input
- add support for json-like dict as input
- avoid deprecation warnings about invalid escape sequences in regex patterns
- add support for mj-font, mj-preview and mj-raw
- better error message for unknown tags


0.5.4 (2021-01-15)
------------------

- handle `<mj-head>` section containing HTML comments
- also render attributes with empty values if set explicitely
- implement (basic) support for mj-class
- port "Component.allowedAttributes" from JS mjml
- ability to render "welcome-email.mjml" from "mjmlio/email-templates"


0.5.3 (2020-10-29)
------------------

- stop shipping tests in wheel
- move all requirements to setup.cfg


0.5.2 (2020-09-21)
------------------

- mjml: always return "binary" data (UTF-8) to avoid encoding problems in Windows


0.5.1 (2021-08-20)
------------------

- mjml script: use setuptools-based wrapper so Windows users can run it more easily
